==> jc-1.4.0.tar.gz: gnu/java/net/protocol/ftp/BlockInputStream.h <==
// class gnu.java.net.protocol.ftp.BlockInputStream

// class file dependencies
// @dep_class 44d489a6f8cebe70 gnu_java_net_protocol_ftp_BlockInputStream
// @dep_class d85c82adc9496692 gnu_java_net_protocol_ftp_DTPInputStream
// @dep_class 455accfa535f5dfe java_io_FilterInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_net_protocol_ftp_DTPInputStream

#include "gnu/java/net/protocol/ftp/DTPInputStream.h"

#ifndef _JC_gnu_java_net_protocol_ftp_BlockInputStream_H_
#define _JC_gnu_java_net_protocol_ftp_BlockInputStream_H_

// Forward structure declarations
struct _jc_gnu_java_net_protocol_ftp_DTP$object;
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$sub_refs	_jc_gnu_java_net_protocol_ftp_BlockInputStream$sub_refs;
typedef struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$sub_nonrefs	_jc_gnu_java_net_protocol_ftp_BlockInputStream$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$refs	_jc_gnu_java_net_protocol_ftp_BlockInputStream$refs;
typedef struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$nonrefs	_jc_gnu_java_net_protocol_ftp_BlockInputStream$nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$object	_jc_gnu_java_net_protocol_ftp_BlockInputStream$object;

typedef struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$fields_struct	_jc_gnu_java_net_protocol_ftp_BlockInputStream$fields_struct;
typedef const struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$vmethods	_jc_gnu_java_net_protocol_ftp_BlockInputStream$vmethods;
typedef const struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$vtable	_jc_gnu_java_net_protocol_ftp_BlockInputStream$vtable;
typedef const struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$vtype	_jc_gnu_java_net_protocol_ftp_BlockInputStream$vtype;

// Class fields structure
struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$fields_struct {
	jint	EOF;
};
extern _jc_gnu_java_net_protocol_ftp_BlockInputStream$fields_struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$class_fields;

// Constructors
extern void _jc_gnu_java_net_protocol_ftp_BlockInputStream$method$_init$6ecf86878bba3fe8(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$object *, struct _jc_object *, struct _jc_java_io_InputStream$object *);

// Virtual methods
extern jint _jc_gnu_java_net_protocol_ftp_BlockInputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$object *);
extern jint _jc_gnu_java_net_protocol_ftp_BlockInputStream$method$read$c38dd905b7fb8654(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$object *, struct _jc_byte_array *);
extern jint _jc_gnu_java_net_protocol_ftp_BlockInputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$object *, struct _jc_byte_array *, jint, jint);
extern void _jc_gnu_java_net_protocol_ftp_BlockInputStream$method$readHeader$315d703f8609c43e(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$object *);
extern void _jc_gnu_java_net_protocol_ftp_BlockInputStream$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_ftp_BlockInputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_gnu_java_net_protocol_ftp_BlockInputStream$method_info$read$c38dd905b7fb8654;
extern _jc_method _jc_gnu_java_net_protocol_ftp_BlockInputStream$method_info$read$e6b6c87b9f256783;
extern _jc_method _jc_gnu_java_net_protocol_ftp_BlockInputStream$method_info$readHeader$315d703f8609c43e;
extern _jc_method _jc_gnu_java_net_protocol_ftp_BlockInputStream$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$vmethods {
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$object *);
	jint	(*read$c38dd905b7fb8654)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$object *, struct _jc_byte_array *);
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$object *, struct _jc_byte_array *, jint, jint);
	void	(*readHeader$315d703f8609c43e)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$object *);
};

// Vtable
struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_FilterInputStream$vmethods	java_io_FilterInputStream;
	_jc_gnu_java_net_protocol_ftp_DTPInputStream$vmethods	gnu_java_net_protocol_ftp_DTPInputStream;
	_jc_gnu_java_net_protocol_ftp_BlockInputStream$vmethods	gnu_java_net_protocol_ftp_BlockInputStream;
};

// Vtype
struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_ftp_BlockInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$refs {
    _jc_gnu_java_net_protocol_ftp_BlockInputStream$sub_refs	gnu_java_net_protocol_ftp_BlockInputStream;
    _jc_gnu_java_net_protocol_ftp_DTPInputStream$sub_refs	gnu_java_net_protocol_ftp_DTPInputStream;
    _jc_java_io_FilterInputStream$sub_refs	java_io_FilterInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$sub_nonrefs {
	jint	descriptor;
	jint	max;
	jint	count;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_FilterInputStream$sub_nonrefs	java_io_FilterInputStream;
    _jc_gnu_java_net_protocol_ftp_DTPInputStream$sub_nonrefs	gnu_java_net_protocol_ftp_DTPInputStream;
    _jc_gnu_java_net_protocol_ftp_BlockInputStream$sub_nonrefs	gnu_java_net_protocol_ftp_BlockInputStream;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$object {
	_jc_gnu_java_net_protocol_ftp_BlockInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_ftp_BlockInputStream$vtype	*vtype;
	_jc_gnu_java_net_protocol_ftp_BlockInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_ftp_BlockInputStream$vtype _jc_gnu_java_net_protocol_ftp_BlockInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_ftp_BlockInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_ftp_BlockInputStream$class_object;

#endif	/* _JC_gnu_java_net_protocol_ftp_BlockInputStream_H_ */

==> jc-1.4.6.tar.gz: gnu/java/net/protocol/ftp/BlockInputStream.h <==
// class gnu.java.net.protocol.ftp.BlockInputStream

// class file dependencies
// @dep_class 44d489a6f8cebe70 gnu_java_net_protocol_ftp_BlockInputStream
// @dep_class d85c82adc9496692 gnu_java_net_protocol_ftp_DTPInputStream
// @dep_class 455accfa535f5dfe java_io_FilterInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_net_protocol_ftp_DTPInputStream

#include "gnu/java/net/protocol/ftp/DTPInputStream.h"

#ifndef _JC_gnu_java_net_protocol_ftp_BlockInputStream_H_
#define _JC_gnu_java_net_protocol_ftp_BlockInputStream_H_

// Forward structure declarations
struct _jc_gnu_java_net_protocol_ftp_DTP$object;
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$sub_refs	_jc_gnu_java_net_protocol_ftp_BlockInputStream$sub_refs;
typedef struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$sub_nonrefs	_jc_gnu_java_net_protocol_ftp_BlockInputStream$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$refs	_jc_gnu_java_net_protocol_ftp_BlockInputStream$refs;
typedef struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$nonrefs	_jc_gnu_java_net_protocol_ftp_BlockInputStream$nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$object	_jc_gnu_java_net_protocol_ftp_BlockInputStream$object;

typedef struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$fields_struct	_jc_gnu_java_net_protocol_ftp_BlockInputStream$fields_struct;
typedef const struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$vmethods	_jc_gnu_java_net_protocol_ftp_BlockInputStream$vmethods;
typedef const struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$vtable	_jc_gnu_java_net_protocol_ftp_BlockInputStream$vtable;
typedef const struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$vtype	_jc_gnu_java_net_protocol_ftp_BlockInputStream$vtype;

// Class fields structure
struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$fields_struct {
	jint	EOF;
};
extern _jc_gnu_java_net_protocol_ftp_BlockInputStream$fields_struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$class_fields;

// Constructors
extern void _jc_gnu_java_net_protocol_ftp_BlockInputStream$method$_init$6ecf86878bba3fe8(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$object *, struct _jc_object *, struct _jc_java_io_InputStream$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_gnu_java_net_protocol_ftp_BlockInputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_net_protocol_ftp_BlockInputStream$method$read$c38dd905b7fb8654(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_net_protocol_ftp_BlockInputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_gnu_java_net_protocol_ftp_BlockInputStream$method$readHeader$315d703f8609c43e(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_net_protocol_ftp_BlockInputStream$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_ftp_BlockInputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_gnu_java_net_protocol_ftp_BlockInputStream$method_info$read$c38dd905b7fb8654;
extern _jc_method _jc_gnu_java_net_protocol_ftp_BlockInputStream$method_info$read$e6b6c87b9f256783;
extern _jc_method _jc_gnu_java_net_protocol_ftp_BlockInputStream$method_info$readHeader$315d703f8609c43e;
extern _jc_method _jc_gnu_java_net_protocol_ftp_BlockInputStream$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$vmethods {
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$object *) _JC_JCNI_ATTR;
	jint	(*read$c38dd905b7fb8654)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
	void	(*readHeader$315d703f8609c43e)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_FilterInputStream$vmethods	java_io_FilterInputStream;
	_jc_gnu_java_net_protocol_ftp_DTPInputStream$vmethods	gnu_java_net_protocol_ftp_DTPInputStream;
	_jc_gnu_java_net_protocol_ftp_BlockInputStream$vmethods	gnu_java_net_protocol_ftp_BlockInputStream;
};

// Vtype
struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_ftp_BlockInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$refs {
    _jc_gnu_java_net_protocol_ftp_BlockInputStream$sub_refs	gnu_java_net_protocol_ftp_BlockInputStream;
    _jc_gnu_java_net_protocol_ftp_DTPInputStream$sub_refs	gnu_java_net_protocol_ftp_DTPInputStream;
    _jc_java_io_FilterInputStream$sub_refs	java_io_FilterInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$sub_nonrefs {
	jint	descriptor;
	jint	max;
	jint	count;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_FilterInputStream$sub_nonrefs	java_io_FilterInputStream;
    _jc_gnu_java_net_protocol_ftp_DTPInputStream$sub_nonrefs	gnu_java_net_protocol_ftp_DTPInputStream;
    _jc_gnu_java_net_protocol_ftp_BlockInputStream$sub_nonrefs	gnu_java_net_protocol_ftp_BlockInputStream;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_ftp_BlockInputStream$object {
	_jc_gnu_java_net_protocol_ftp_BlockInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_ftp_BlockInputStream$vtype	*vtype;
	_jc_gnu_java_net_protocol_ftp_BlockInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_ftp_BlockInputStream$vtype _jc_gnu_java_net_protocol_ftp_BlockInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_ftp_BlockInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_ftp_BlockInputStream$class_object;

#endif	/* _JC_gnu_java_net_protocol_ftp_BlockInputStream_H_ */
